@@ -773,7 +773,6 @@ class Video:
         """
         self.credential.raise_for_no_sessdata
         self.credential.raise_for_no_bili_jct()
-        self.credential.raise_for_no_buvid3()
 
         api = API["operate"]["like"]
         data = {
@@ -1038,7 +1037,7 @@ class VideoOnlineMonitor(AsyncEvent):
             'https://api.bilibili.com/x/web-interface/broadcast/servers?platform=pc',
             credential=self.credential)
 
-        uri = f"wss://{resp['domain']}:{resp['wssPort']}/sub"
+        uri = f"wss://{resp['domain']}:{resp['wss_port']}/sub"
         self.__heartbeat_interval = resp['heartbeat']
         self.logger.debug(f'服务器信息获取成功，URI：{uri}')
 
@@ -1204,446 +1203,3 @@ class VideoOnlineMonitor(AsyncEvent):
             })
             offset += region_header[0]
         return tuple(real_data)
-
-
-class VideoUploaderPageObject:
-    """
-    视频上传分 P 对象。
-    """
-
-    def __init__(self, video_stream: io.BufferedIOBase, title: str, video_format: str = "mp4", description: str = ""):
-        """
-        Args:
-            video_stream (io.BufferedIOBase): 分 P 视频流。可以是 `open()` 返回的 FileIO 对象。
-            title        (str)              : 分 P 标题。
-            video_format (str)              : 分 P 的视频格式。可以是 mp4, mkv, mov, wmv。 Default to "mp4"。
-            description  (str, optional)    : 分 P 描述。 Defaults to ""。
-        """
-        self.__stream = video_stream
-        self.title = title
-        self.video_format = video_format
-        self.description = description
-        self.__total_size = None
-
-    def get_total_size(self):
-        """
-        获取总大小。
-
-        Returns:
-            int: 视频流总大小。
-        """
-        if self.__total_size is None:
-            self.__stream.seek(0)
-            self.__total_size = len(self.__stream.read())
-        return self.__total_size
-
-    def get_stream(self):
-        """
-        获取视频流。
-
-        Returns:
-            io.BufferedIOBase: 视频流
-        """
-        return self.__stream
-
-
-class VideoUploader(AsyncEvent):
-    """
-    视频上传。任何上传中的出错将会直接抛出错误并终止上传。
-
-    | name         | description       | callback                                                     |
-    | ------------ | ----------------- | ------------------------------------------------------------ |
-    | COVER_BEGIN  | 准备上传封面      | None                                                         |
-    | COVER_END    | 封面上传成功      | str: 封面 URL。                                              |
-    | PAGE_BEGIN   | 开始上传分 P      | VideoUploaderPageObject: 当前分 P 对象                       |
-    | CHUNK_BEGIN  | 开始上传分 P 分块 | {
-                                            "page": VideoUploaderPageObject #  分 P 对象,
-                                            "chunk_index": int,   # 区块编号
-                                            "total_chunk": int,   # 总区块数量
-                                            "range": Tuple[int, int]  # 数据范围
-                                        } |
-    | CHUNK_END    | 分块上传结束      | 同 CHUNK_BEGIN                                               |
-    | PAGE_END     | 分 P 上传结束     | VideoUploaderPageObject: 当前分 P 对象                       |
-    | SUBMIT_BEGIN | 准备提交视频      | dict: 准备提交的数据                                         |
-    | SUBMIT_END   | 提交视频结束      | dict: 调用 API 返回结果                                      |
-    """
-
-    def __init__(self,
-                 cover: io.BufferedIOBase,
-                 cover_type: str,
-                 pages: List[VideoUploaderPageObject],
-                 config: dict,
-                 credential: Credential):
-        """
-        Args:
-            cover      (io.BufferedIOBase)            : 封面 io 类，比如调用 open() 打开文件后的返回值。
-            cover_type (str)                          : 封面数据 MIME 类型。常见类型对照 jpg: image/jpeg, png: image/png
-            pages      (List[VideoUploaderPageObject]): 分 P 视频列表。
-            config     (dict)                         : 视频信息，格式参照 self.set_config()
-            credential (Credential)                   : Credential 类。
-        """
-        super().__init__()
-        self.cover = cover
-        self.cover_type = cover_type
-        self.pages = pages
-        self.__config = {}
-        self.__session = get_session()
-        self.credential = credential
-
-        credential.raise_for_no_sessdata()
-        credential.raise_for_no_bili_jct()
-
-        self.set_config(config)
-
-    def set_config(self, config: dict):
-        """
-        设置上传配置。
-
-        不可设置的参数：cover, videos。
-
-        参考如下：
-
-        ```json
-        {
-            "copyright": "int, 投稿类型。1 自制，2 转载。",
-            "source": "str, 视频来源。投稿类型为转载时注明来源，为原创时为空。",
-            "cover": "str, 封面 URL。。",
-            "desc": "str, 视频简介。",
-            "desc_format_id": 0,
-            "dynamic": "str, 动态信息。",
-            "interactive": 0,
-            "open_elec": "int, 是否展示充电信息。1 为是，0 为否。",
-            "no_reprint": "int, 显示未经作者授权禁止转载，仅当为原创视频时有效。1 为启用，0 为关闭。",
-            "subtitles": {
-                "lan": "字幕语言，不清楚作用请将该项设置为空",
-                "open": 0
-            },
-            "tag": "str, 视频标签。使用英文半角逗号分隔的标签组。示例：标签1,标签2,标签3",
-            "tid": "int, 分区ID。可以使用 channel 模块进行查询。",
-            "title": "视频标题",
-            "up_close_danmaku": "bool, 是否关闭弹幕。",
-            "up_close_reply": "bool, 是否关闭评论。",
-            "videos": [
-                {
-                    "desc": "str, 分 P 描述。",
-                    "filename": "str, 视频上传后的文件名。",
-                    "title": "str, 分 P 标题"
-                }
-            ]
-        }
-        ```
-
-        Args:
-            config (dict): 视频信息
-        """
-        if any(["videos" in config, "cover" in config]):
-            raise ArgsException("不可手动设置参数：cover, videos。将会自动设置。")
-        self.__config = copy(config)
-
-    def get_config(self):
-        """
-        获取视频信息。
-
-        Returns:
-            dict: 视频信息。
-        """
-        return copy(self.__config)
-
-    async def start(self):
-        """
-        开始上传。
-
-        Returns:
-            dict: 包含 bvid 和 aid 的字典。
-        """
-        # 上传封面
-        self.dispatch("COVER_BEGIN")
-        cover_info = await self.__upload_cover()
-        cover_url = cover_info["url"]
-        self.dispatch("COVER_END", cover_url)
-
-        # 上传视频
-        videos = []
-        for page in self.pages:
-            filename = await self.__upload_video(page)
-            videos.append({
-                "filename": filename.split(".")[0], # only need the filename without extension returned from B server
-                "page": page
-            })
-
-        # 提交视频
-        result = await self.__submit(cover_url, videos)
-        return result
-
-    async def __submit(self, cover: str, videos: list):
-        """
-        提交视频。
-
-        Args:
-            cover  (str) : 封面 URL。
-            videos (list): 要提交的视频，格式参照 self.start() 中的代码。
-
-        Returns:
-            dict: 包含 bvid 和 aid 的字典。
-        """
-        config = copy(self.__config)
-        config["cover"] = cover
-        config["videos"] = []
-        for video in videos:
-            v = {
-                "desc": video["page"].description,
-                "title": video["page"].title,
-                "filename": video["filename"],
-                "cid": 0
-            }
-            config["videos"].append(v)
-        data = config
-        params = {
-            "csrf": self.credential.bili_jct
-        }
-        self.dispatch("SUBMIT_BEGIN", config)
-        resp = await request("POST", "https://member.bilibili.com/x/vu/web/add",
-                             data=data,
-                             params=params,
-                             credential=self.credential,
-                             no_csrf=True,
-                             json_body=True)
-        self.dispatch("SUBMIT_END", resp)
-        return resp
-
-    async def __upload_cover(self):
-        """
-        上传视频封面。
-
-        Returns:
-            str: 封面 URL。
-        """
-        b64 = base64.b64encode(self.cover.read())
-        data_url = f"data:{self.cover_type};base64,{b64.decode()}"
-        payload = {
-            "cover": data_url
-        }
-        return await request("POST", "https://member.bilibili.com/x/vu/web/cover/up", data=payload, credential=self.credential)
-
-    async def __upload_video(self, page: VideoUploaderPageObject):
-        """
-        上传视频。
-
-        Args:
-            page (VideoUploaderPageObject): VideoUploaderPageObject。
-
-        Returns:
-            str: filename，用于最后提交视频。
-        """
-        self.dispatch("PAGE_BEGIN", page)
-        # 获取上传信息
-        upload_info = await self.__get_upload_info(page)
-        # 最大并发数
-        threads = upload_info["threads"]
-        # chunk 大小
-        chunk_size = upload_info["chunk_size"]
-        # X-Upos-Auth 头内容
-        auth = upload_info["auth"]
-        # 上传节点
-        endpoint = upload_info["endpoint"]
-        # 上传 URL
-        url = f"https:{endpoint}/{upload_info['upos_uri'][7:]}"
-        # 文件名
-        filename = upload_info["upos_uri"][7:].split("/")[1]
-        # 其他后面会用到的
-        biz_id = upload_info["biz_id"]
-
-        # 获取 upload_id
-        headers = {
-            "User-Agent": "Mozilla/5.0",
-            "Referer": "https://member.bilibili.com",
-            "X-Upos-Auth": auth,
-        }
-        async with self.__session.post(
-                url=url,
-                params={"uploads": "", "output": "json"},
-                headers=headers,
-                cookies=self.credential.get_cookies()) as resp:
-
-            data = await resp.read()
-            data = json.loads(data)
-            upload_id = data["upload_id"]
-
-        # 分配任务
-        total_size = page.get_total_size()
-        # 计算每 chunk 开始位置
-        chunk_offsets = list(range(0, total_size, chunk_size))
-        # 总 chunk 数量
-        total_chunks_count = len(chunk_offsets)
-        # 初始化 chunk
-        chunks = []
-        remain_size = total_size
-
-        stream = page.get_stream()
-        for i, offset in enumerate(chunk_offsets):
-            length = chunk_size if remain_size > chunk_size else remain_size
-            chunks.append(self.__upload_chunk(offset, length, total_size,
-                                              total_chunks_count, stream,
-                                              url, auth, i, upload_id, page))
-            remain_size -= length
-
-        # 分配并发线程
-        tasks = []
-        if len(chunks) <= threads:
-            # chunks 长度比最大并发数小或相等
-            for chunk in chunks:
-                tasks.append(self.__task([chunk]))
-        else:
-            # chunks 长度比最大并发数大
-            chunks_of_every_tasks: List[List[Coroutine]] = []
-            for i in range(threads):
-                chunks_of_every_tasks.append([])
-            i = 0
-            for chunk in chunks:
-                # 平均打散到每个 Task
-                chunks_of_every_tasks[i].append(chunk)
-                i += 1
-                if i >= threads:
-                    i = 0
-            for c in chunks_of_every_tasks:
-                tasks.append(self.__task(c))
-
-        # 开始上传
-        await asyncio.gather(*tasks)
-
-        # 确认是否上传成功
-        params = {
-            "output": "json",
-            "name": page.title,
-            "profile": "ugcupos/bup",
-            "uploadId": upload_id,
-            "biz_id": biz_id
-        }
-        data = {
-            "parts": []
-        }
-        for i in range(total_chunks_count):
-            data["parts"].append({
-                "eTag": "etag",
-                "partNumber": i + 1
-            })
-        headers.update({
-            "Content-Type": "application/json"
-        })
-        async with self.__session.post(
-                url=url,
-                params=params,
-                data=json.dumps(data),
-                headers=headers,
-                cookies=self.credential.get_cookies()) as resp:
-
-            data = await resp.read()
-            data = json.loads(data)
-            if data["OK"] != 1:
-                raise VideoUploadException("上传失败")
-        self.dispatch("PAGE_END", page)
-        return filename
-
-    async def __task(self, chunks: List[Coroutine]):
-        """
-        按顺序执行 chunk coroutine.
-
-        Args:
-            chunks (List[Coroutine]): Coroutine
-        """
-        for chunk in chunks:
-            await chunk
-
-    async def __upload_chunk(self,
-                             start: int,
-                             length: int,
-                             total_size: int,
-                             total_chunks_count: int,
-                             stream: io.BufferedIOBase,
-                             url: str,
-                             auth: str,
-                             index: int,
-                             upload_id: str,
-                             page: VideoUploaderPageObject
-                             ):
-        """
-        上传分块。
-
-        Args:
-            start              (int)                    : 起始位置。
-            length             (int)                    : 长度。
-            total_size         (int)                    : 视频总大小。
-            total_chunks_count (int)                    : 总共分块数量。
-            stream             (io.BufferedIOBase)      : IO 流。
-            url                (str)                    : 上传 URL。
-            auth               (str)                    : X-Upos-Auth 头内容。
-            index              (int)                    : 分块序号。
-            upload_id          (str)                    : upload_id。
-            page               (VideoUploaderPageObject): VideoUploaderPageObject
-        """
-        callback_data = {
-            "page": page,
-            "chunk_index": index + 1,
-            "total_chunk": total_chunks_count,
-            "range": (start, start + length)
-        }
-        self.dispatch("CHUNK_BEGIN", callback_data)
-        headers = {
-            "User-Agent": "Mozilla/5.0",
-            "Referer": "https://member.bilibili.com",
-            "X-Upos-Auth": auth,
-        }
-
-        params = {
-            "partNumber": index + 1,
-            "uploadId": upload_id,
-            "chunk": index,
-            "chunks": total_chunks_count,
-            "size": length,
-            "start": start,
-            "end": start + length,
-            "total": total_size
-        }
-        stream.seek(start)
-        async with self.__session.put(
-                url=url,
-                headers=headers,
-                params=params,
-                data=stream.read(length),
-                cookies=self.credential.get_cookies()) as resp:
-
-            await resp.wait_for_close()
-        self.dispatch("CHUNK_END", callback_data)
-
-    async def __get_upload_info(self, page_object: VideoUploaderPageObject):
-        """
-        获取上传信息。
-
-        Args:
-            page_object (VideoUploaderPageObject): VideoUploaderPageObject。
-        """
-        params = {
-            "name": ".".join([page_object.title, page_object.video_format]),
-            "size": page_object.get_total_size(),
-            "r": "upos",
-            "profile": "ugcupos/bup",
-            "ssl": 0,
-            "version": "2.8.12",
-            "build": 2081200,
-            "upcdn": "bda2",
-            "probe_version": 20200810
-        }
-
-        async with self.__session.get(
-            "https://member.bilibili.com/preupload",
-            params=params,
-            cookies=self.credential.get_cookies(),
-            headers={
-                "User-Agent": "Mozilla/5.0",
-                "Referer": "https://memeber.bilibili.com"
-            }
-        ) as resp:
-            data = await resp.json()
-            if data["OK"] != 1:
-                raise VideoUploadException("获取上传信息失败：" + str(data))
-            return data
